.. code-block::

	 ______   __  __    ______    __   __    ______    __     __
	/\  == \ /\ \_\ \  /\  ___\  /\ "-.\ \  /\  __ \  /\ \  _ \ \
	\ \  _-/ \ \____ \ \ \___  \ \ \ \-.  \ \ \ \/\ \ \ \ \/ ".\ \
	 \ \_\    \/\_____\ \/\_____\ \ \_\\"\_\ \ \_____\ \ \__/".~\_\
	  \/_/     \/_____/  \/_____/  \/_/ \/_/  \/_____/  \/_/   \/_/
			- a Python library for the ServiceNow REST API
			
.. image:: https://travis-ci.org/rbw0/pysnow.svg?branch=master
    :target: https://travis-ci.org/rbw0/pysnow
.. image:: https://coveralls.io/repos/github/rbw0/pysnow/badge.svg?branch=master
    :target: https://coveralls.io/github/rbw0/pysnow?branch=master
.. image:: https://badge.fury.io/py/pysnow.svg
    :target: https://pypi.python.org/pypi/pysnow
.. image:: https://img.shields.io/badge/License-MIT-green.svg
    :target: https://opensource.org/licenses/MIT


Documentation
-------------

The `documentation <http://pysnow.readthedocs.org/>`_ is divided into four sections:

 - `General <http://pysnow.readthedocs.io/en/latest/#general>`_ (install, compatibility etc)
 - `Library API <http://pysnow.readthedocs.io/en/latest/#api>`_
 - `Usage <http://pysnow.readthedocs.io/en/latest/#usage>`_
 - `Full examples <http://pysnow.readthedocs.io/en/latest/#examples>`_


Author
------
Created by Robert Wikman <rbw@vault13.org> in 2016


Contributors
------------
lingfish, jcpunk, AMMullan, amontalban, ryancurrah, jdugan1024, punkrokk


JetBrains
---------
Thank you Jetbrains (www.jetbrains.com) for supporting with IDE licenses!
